import { html } from 'lit-html';
const meta = {
    title: 'Dialog',
    component: 'zero-dialog',
};
export default meta;
const showDialog = (e) => {
    const dialog = document.querySelector('zero-dialog');
    dialog.show();
};
const showEmptyDialog = (e) => {
    const dialog = document.getElementById('empty-dialog');
    dialog.show();
};
const closeDialog = (e) => {
    const dialog = document.querySelector('zero-dialog');
    dialog.close();
};
const dialogNotifyId = 'dialogNotify';
const showDialogNotify = (notifyText, dialogType) => {
    const dialogNotify = document.createElement('zero-dialog');
    dialogNotify.setAttribute('id', dialogNotifyId);
    dialogNotify.type = dialogType;
    dialogNotify.notification = {
        title: 'Notify Title',
        body: `${notifyText} ID - notify - ${Math.random()}`,
        config: {
            dialog: {
                confirmingActions: [
                    {
                        label: 'Action',
                        action: () => {
                            alert('Action in progress');
                        },
                    },
                ],
            },
        },
    };
    const container = document.getElementById('dialog-container');
    container.appendChild(dialogNotify);
    dialogNotify.show();
};
export const Primary = {
    argTypes: {
        dialogType: {
            control: 'select',
            options: ['default', 'error', 'success'],
        },
    },
    args: {
        notifyText: 'Lorem ipsum dolor sit amet consectetur adipisicing elit. Lorem ipsum dolor sit amet',
        dialogMaxWidth: '557px',
        dialogTitle: 'Dialog title',
        dialogInitialText: 'Some text in a Zero Dialog',
        dialogMainText: `Lorem ipsum dolor sit amet consectetur adipisicing elit. Quis similique iste ab sed
      voluptatem ut suscipit tenetur distinctio? Quo est debitis pariatur qui quisquam repudiandae
      at atque et quibusdam rerum, reprehenderit sed laborum officiis distinctio dolorum
      temporibus aperiam dolor consequatur perferendis aspernatur fugit repellendus asperiores,
      voluptas illo? Voluptatum, atque quidem?`,
        dialogCloseButtonText: 'Close this dialog',
        dialogType: 'default',
    },
    render: ({ notifyText, dialogMaxWidth, dialogTitle, dialogInitialText, dialogMainText, dialogCloseButtonText, dialogType, }) => {
        var _a;
        (_a = document.getElementById(dialogNotifyId)) === null || _a === void 0 ? void 0 : _a.remove();
        return html `
      <zero-button @click="${showDialog}">Show Zero Dialog</zero-button>
      <zero-button @click="${showEmptyDialog}">Show Empty Dialog</zero-button>
      <zero-button @click="${() => showDialogNotify(notifyText, dialogType)}">
        Show Zero Dialog - Notification Structure ${dialogType}
      </zero-button>
      <div id="dialog-container"></div>
      <zero-dialog style="--dialog-max-width: ${dialogMaxWidth};" type=${dialogType}>
        <h5 slot="top">${dialogTitle}</h5>
        <p>${dialogInitialText}</p>
        <p>${dialogMainText}</p>
        <zero-divider slot="bottom"></zero-divider>
        <zero-button appearance="primary-gradient" slot="bottom" @click="${closeDialog}">
          ${dialogCloseButtonText}
        </zero-button>
      </zero-dialog>
      <zero-dialog id="empty-dialog"></zero-dialog>
    `;
    },
};
